###########
postprocess
###########

.. automodule:: mola.cfd.postprocess
    :members:

.. automodule:: mola.cfd.postprocess.extractions
    :members:

.. automodule:: mola.cfd.postprocess.signals
    :members:

.. automodule:: mola.cfd.postprocess.signals.tree_manipulation
    :members:
    :private-members:

.. automodule:: mola.cfd.postprocess.extractions_with_cassiopee
    :members:

.. automodule:: mola.cfd.postprocess.extractions_with_maia
    :members:

.. automodule:: mola.cfd.postprocess.interpolation
    :members:

.. automodule:: mola.cfd.postprocess.remove_cfd_files
    :members:

